# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateServiceCatalogAssociationDetails(object):
    """
    The model to create a single association between a service catalog and a resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateServiceCatalogAssociationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service_catalog_id:
            The value to assign to the service_catalog_id property of this CreateServiceCatalogAssociationDetails.
        :type service_catalog_id: str

        :param entity_id:
            The value to assign to the entity_id property of this CreateServiceCatalogAssociationDetails.
        :type entity_id: str

        :param entity_type:
            The value to assign to the entity_type property of this CreateServiceCatalogAssociationDetails.
        :type entity_type: str

        """
        self.swagger_types = {
            'service_catalog_id': 'str',
            'entity_id': 'str',
            'entity_type': 'str'
        }

        self.attribute_map = {
            'service_catalog_id': 'serviceCatalogId',
            'entity_id': 'entityId',
            'entity_type': 'entityType'
        }

        self._service_catalog_id = None
        self._entity_id = None
        self._entity_type = None

    @property
    def service_catalog_id(self):
        """
        **[Required]** Gets the service_catalog_id of this CreateServiceCatalogAssociationDetails.
        Identifier of the service catalog.


        :return: The service_catalog_id of this CreateServiceCatalogAssociationDetails.
        :rtype: str
        """
        return self._service_catalog_id

    @service_catalog_id.setter
    def service_catalog_id(self, service_catalog_id):
        """
        Sets the service_catalog_id of this CreateServiceCatalogAssociationDetails.
        Identifier of the service catalog.


        :param service_catalog_id: The service_catalog_id of this CreateServiceCatalogAssociationDetails.
        :type: str
        """
        self._service_catalog_id = service_catalog_id

    @property
    def entity_id(self):
        """
        **[Required]** Gets the entity_id of this CreateServiceCatalogAssociationDetails.
        Identifier of the entity being associated with service catalog.


        :return: The entity_id of this CreateServiceCatalogAssociationDetails.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this CreateServiceCatalogAssociationDetails.
        Identifier of the entity being associated with service catalog.


        :param entity_id: The entity_id of this CreateServiceCatalogAssociationDetails.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_type(self):
        """
        Gets the entity_type of this CreateServiceCatalogAssociationDetails.
        The type of the entity that is associated with the service catalog.


        :return: The entity_type of this CreateServiceCatalogAssociationDetails.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this CreateServiceCatalogAssociationDetails.
        The type of the entity that is associated with the service catalog.


        :param entity_type: The entity_type of this CreateServiceCatalogAssociationDetails.
        :type: str
        """
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSessionDetails(object):
    """
    The configuration details for a new bastion session. A session lets authorized users connect to a target resource for a predetermined amount of time. The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.
    """

    #: A constant which can be used with the key_type property of a CreateSessionDetails.
    #: This constant has a value of "PUB"
    KEY_TYPE_PUB = "PUB"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSessionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateSessionDetails.
        :type display_name: str

        :param bastion_id:
            The value to assign to the bastion_id property of this CreateSessionDetails.
        :type bastion_id: str

        :param target_resource_details:
            The value to assign to the target_resource_details property of this CreateSessionDetails.
        :type target_resource_details: oci.bastion.models.CreateSessionTargetResourceDetails

        :param key_type:
            The value to assign to the key_type property of this CreateSessionDetails.
            Allowed values for this property are: "PUB"
        :type key_type: str

        :param key_details:
            The value to assign to the key_details property of this CreateSessionDetails.
        :type key_details: oci.bastion.models.PublicKeyDetails

        :param session_ttl_in_seconds:
            The value to assign to the session_ttl_in_seconds property of this CreateSessionDetails.
        :type session_ttl_in_seconds: int

        """
        self.swagger_types = {
            'display_name': 'str',
            'bastion_id': 'str',
            'target_resource_details': 'CreateSessionTargetResourceDetails',
            'key_type': 'str',
            'key_details': 'PublicKeyDetails',
            'session_ttl_in_seconds': 'int'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'bastion_id': 'bastionId',
            'target_resource_details': 'targetResourceDetails',
            'key_type': 'keyType',
            'key_details': 'keyDetails',
            'session_ttl_in_seconds': 'sessionTtlInSeconds'
        }

        self._display_name = None
        self._bastion_id = None
        self._target_resource_details = None
        self._key_type = None
        self._key_details = None
        self._session_ttl_in_seconds = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateSessionDetails.
        The name of the session.


        :return: The display_name of this CreateSessionDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateSessionDetails.
        The name of the session.


        :param display_name: The display_name of this CreateSessionDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def bastion_id(self):
        """
        **[Required]** Gets the bastion_id of this CreateSessionDetails.
        The unique identifier (OCID) of the bastion on which to create this session.


        :return: The bastion_id of this CreateSessionDetails.
        :rtype: str
        """
        return self._bastion_id

    @bastion_id.setter
    def bastion_id(self, bastion_id):
        """
        Sets the bastion_id of this CreateSessionDetails.
        The unique identifier (OCID) of the bastion on which to create this session.


        :param bastion_id: The bastion_id of this CreateSessionDetails.
        :type: str
        """
        self._bastion_id = bastion_id

    @property
    def target_resource_details(self):
        """
        **[Required]** Gets the target_resource_details of this CreateSessionDetails.

        :return: The target_resource_details of this CreateSessionDetails.
        :rtype: oci.bastion.models.CreateSessionTargetResourceDetails
        """
        return self._target_resource_details

    @target_resource_details.setter
    def target_resource_details(self, target_resource_details):
        """
        Sets the target_resource_details of this CreateSessionDetails.

        :param target_resource_details: The target_resource_details of this CreateSessionDetails.
        :type: oci.bastion.models.CreateSessionTargetResourceDetails
        """
        self._target_resource_details = target_resource_details

    @property
    def key_type(self):
        """
        Gets the key_type of this CreateSessionDetails.
        The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.

        Allowed values for this property are: "PUB"


        :return: The key_type of this CreateSessionDetails.
        :rtype: str
        """
        return self._key_type

    @key_type.setter
    def key_type(self, key_type):
        """
        Sets the key_type of this CreateSessionDetails.
        The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.


        :param key_type: The key_type of this CreateSessionDetails.
        :type: str
        """
        allowed_values = ["PUB"]
        if not value_allowed_none_or_none_sentinel(key_type, allowed_values):
            raise ValueError(
                "Invalid value for `key_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._key_type = key_type

    @property
    def key_details(self):
        """
        **[Required]** Gets the key_details of this CreateSessionDetails.

        :return: The key_details of this CreateSessionDetails.
        :rtype: oci.bastion.models.PublicKeyDetails
        """
        return self._key_details

    @key_details.setter
    def key_details(self, key_details):
        """
        Sets the key_details of this CreateSessionDetails.

        :param key_details: The key_details of this CreateSessionDetails.
        :type: oci.bastion.models.PublicKeyDetails
        """
        self._key_details = key_details

    @property
    def session_ttl_in_seconds(self):
        """
        Gets the session_ttl_in_seconds of this CreateSessionDetails.
        The amount of time the session can remain active.


        :return: The session_ttl_in_seconds of this CreateSessionDetails.
        :rtype: int
        """
        return self._session_ttl_in_seconds

    @session_ttl_in_seconds.setter
    def session_ttl_in_seconds(self, session_ttl_in_seconds):
        """
        Sets the session_ttl_in_seconds of this CreateSessionDetails.
        The amount of time the session can remain active.


        :param session_ttl_in_seconds: The session_ttl_in_seconds of this CreateSessionDetails.
        :type: int
        """
        self._session_ttl_in_seconds = session_ttl_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .api_specification_route_backend import ApiSpecificationRouteBackend
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OracleFunctionBackend(ApiSpecificationRouteBackend):
    """
    Send the request to an Oracle Functions function.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OracleFunctionBackend object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.OracleFunctionBackend.type` attribute
        of this class is ``ORACLE_FUNCTIONS_BACKEND`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this OracleFunctionBackend.
            Allowed values for this property are: "ORACLE_FUNCTIONS_BACKEND", "HTTP_BACKEND", "STOCK_RESPONSE_BACKEND"
        :type type: str

        :param function_id:
            The value to assign to the function_id property of this OracleFunctionBackend.
        :type function_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'function_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'function_id': 'functionId'
        }

        self._type = None
        self._function_id = None
        self._type = 'ORACLE_FUNCTIONS_BACKEND'

    @property
    def function_id(self):
        """
        **[Required]** Gets the function_id of this OracleFunctionBackend.
        The `OCID`__ of the Oracle Functions function resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The function_id of this OracleFunctionBackend.
        :rtype: str
        """
        return self._function_id

    @function_id.setter
    def function_id(self, function_id):
        """
        Sets the function_id of this OracleFunctionBackend.
        The `OCID`__ of the Oracle Functions function resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param function_id: The function_id of this OracleFunctionBackend.
        :type: str
        """
        self._function_id = function_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PropertyDefinition(object):
    """
    Details of a single type property.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PropertyDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this PropertyDefinition.
        :type name: str

        :param type:
            The value to assign to the type property of this PropertyDefinition.
        :type type: str

        :param is_required:
            The value to assign to the is_required property of this PropertyDefinition.
        :type is_required: bool

        :param is_updatable:
            The value to assign to the is_updatable property of this PropertyDefinition.
        :type is_updatable: bool

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'is_required': 'bool',
            'is_updatable': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'is_required': 'isRequired',
            'is_updatable': 'isUpdatable'
        }

        self._name = None
        self._type = None
        self._is_required = None
        self._is_updatable = None

    @property
    def name(self):
        """
        Gets the name of this PropertyDefinition.
        Name of the property.


        :return: The name of this PropertyDefinition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PropertyDefinition.
        Name of the property.


        :param name: The name of this PropertyDefinition.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this PropertyDefinition.
        The properties value type.


        :return: The type of this PropertyDefinition.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PropertyDefinition.
        The properties value type.


        :param type: The type of this PropertyDefinition.
        :type: str
        """
        self._type = type

    @property
    def is_required(self):
        """
        Gets the is_required of this PropertyDefinition.
        Whether instances of the type are required to set this property.


        :return: The is_required of this PropertyDefinition.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this PropertyDefinition.
        Whether instances of the type are required to set this property.


        :param is_required: The is_required of this PropertyDefinition.
        :type: bool
        """
        self._is_required = is_required

    @property
    def is_updatable(self):
        """
        Gets the is_updatable of this PropertyDefinition.
        Indicates if this property value can be updated.


        :return: The is_updatable of this PropertyDefinition.
        :rtype: bool
        """
        return self._is_updatable

    @is_updatable.setter
    def is_updatable(self, is_updatable):
        """
        Sets the is_updatable of this PropertyDefinition.
        Indicates if this property value can be updated.


        :param is_updatable: The is_updatable of this PropertyDefinition.
        :type: bool
        """
        self._is_updatable = is_updatable

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperationsInsightsConfig(object):
    """
    The configuration of Operations Insights for the external database
    """

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "ENABLING"
    OPERATIONS_INSIGHTS_STATUS_ENABLING = "ENABLING"

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "ENABLED"
    OPERATIONS_INSIGHTS_STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "DISABLING"
    OPERATIONS_INSIGHTS_STATUS_DISABLING = "DISABLING"

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "NOT_ENABLED"
    OPERATIONS_INSIGHTS_STATUS_NOT_ENABLED = "NOT_ENABLED"

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "FAILED_ENABLING"
    OPERATIONS_INSIGHTS_STATUS_FAILED_ENABLING = "FAILED_ENABLING"

    #: A constant which can be used with the operations_insights_status property of a OperationsInsightsConfig.
    #: This constant has a value of "FAILED_DISABLING"
    OPERATIONS_INSIGHTS_STATUS_FAILED_DISABLING = "FAILED_DISABLING"

    def __init__(self, **kwargs):
        """
        Initializes a new OperationsInsightsConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operations_insights_status:
            The value to assign to the operations_insights_status property of this OperationsInsightsConfig.
            Allowed values for this property are: "ENABLING", "ENABLED", "DISABLING", "NOT_ENABLED", "FAILED_ENABLING", "FAILED_DISABLING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operations_insights_status: str

        :param operations_insights_connector_id:
            The value to assign to the operations_insights_connector_id property of this OperationsInsightsConfig.
        :type operations_insights_connector_id: str

        """
        self.swagger_types = {
            'operations_insights_status': 'str',
            'operations_insights_connector_id': 'str'
        }

        self.attribute_map = {
            'operations_insights_status': 'operationsInsightsStatus',
            'operations_insights_connector_id': 'operationsInsightsConnectorId'
        }

        self._operations_insights_status = None
        self._operations_insights_connector_id = None

    @property
    def operations_insights_status(self):
        """
        **[Required]** Gets the operations_insights_status of this OperationsInsightsConfig.
        The status of Operations Insights

        Allowed values for this property are: "ENABLING", "ENABLED", "DISABLING", "NOT_ENABLED", "FAILED_ENABLING", "FAILED_DISABLING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operations_insights_status of this OperationsInsightsConfig.
        :rtype: str
        """
        return self._operations_insights_status

    @operations_insights_status.setter
    def operations_insights_status(self, operations_insights_status):
        """
        Sets the operations_insights_status of this OperationsInsightsConfig.
        The status of Operations Insights


        :param operations_insights_status: The operations_insights_status of this OperationsInsightsConfig.
        :type: str
        """
        allowed_values = ["ENABLING", "ENABLED", "DISABLING", "NOT_ENABLED", "FAILED_ENABLING", "FAILED_DISABLING"]
        if not value_allowed_none_or_none_sentinel(operations_insights_status, allowed_values):
            operations_insights_status = 'UNKNOWN_ENUM_VALUE'
        self._operations_insights_status = operations_insights_status

    @property
    def operations_insights_connector_id(self):
        """
        Gets the operations_insights_connector_id of this OperationsInsightsConfig.
        The `OCID`__ of the
        :func:`create_external_database_connector_details`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The operations_insights_connector_id of this OperationsInsightsConfig.
        :rtype: str
        """
        return self._operations_insights_connector_id

    @operations_insights_connector_id.setter
    def operations_insights_connector_id(self, operations_insights_connector_id):
        """
        Sets the operations_insights_connector_id of this OperationsInsightsConfig.
        The `OCID`__ of the
        :func:`create_external_database_connector_details`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param operations_insights_connector_id: The operations_insights_connector_id of this OperationsInsightsConfig.
        :type: str
        """
        self._operations_insights_connector_id = operations_insights_connector_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseConnectionStrings(object):
    """
    Connection strings to connect to an Oracle Database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseConnectionStrings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cdb_default:
            The value to assign to the cdb_default property of this DatabaseConnectionStrings.
        :type cdb_default: str

        :param cdb_ip_default:
            The value to assign to the cdb_ip_default property of this DatabaseConnectionStrings.
        :type cdb_ip_default: str

        :param all_connection_strings:
            The value to assign to the all_connection_strings property of this DatabaseConnectionStrings.
        :type all_connection_strings: dict(str, str)

        """
        self.swagger_types = {
            'cdb_default': 'str',
            'cdb_ip_default': 'str',
            'all_connection_strings': 'dict(str, str)'
        }

        self.attribute_map = {
            'cdb_default': 'cdbDefault',
            'cdb_ip_default': 'cdbIpDefault',
            'all_connection_strings': 'allConnectionStrings'
        }

        self._cdb_default = None
        self._cdb_ip_default = None
        self._all_connection_strings = None

    @property
    def cdb_default(self):
        """
        Gets the cdb_default of this DatabaseConnectionStrings.
        Host name based CDB Connection String.


        :return: The cdb_default of this DatabaseConnectionStrings.
        :rtype: str
        """
        return self._cdb_default

    @cdb_default.setter
    def cdb_default(self, cdb_default):
        """
        Sets the cdb_default of this DatabaseConnectionStrings.
        Host name based CDB Connection String.


        :param cdb_default: The cdb_default of this DatabaseConnectionStrings.
        :type: str
        """
        self._cdb_default = cdb_default

    @property
    def cdb_ip_default(self):
        """
        Gets the cdb_ip_default of this DatabaseConnectionStrings.
        IP based CDB Connection String.


        :return: The cdb_ip_default of this DatabaseConnectionStrings.
        :rtype: str
        """
        return self._cdb_ip_default

    @cdb_ip_default.setter
    def cdb_ip_default(self, cdb_ip_default):
        """
        Sets the cdb_ip_default of this DatabaseConnectionStrings.
        IP based CDB Connection String.


        :param cdb_ip_default: The cdb_ip_default of this DatabaseConnectionStrings.
        :type: str
        """
        self._cdb_ip_default = cdb_ip_default

    @property
    def all_connection_strings(self):
        """
        Gets the all_connection_strings of this DatabaseConnectionStrings.
        All connection strings to use to connect to the Database.


        :return: The all_connection_strings of this DatabaseConnectionStrings.
        :rtype: dict(str, str)
        """
        return self._all_connection_strings

    @all_connection_strings.setter
    def all_connection_strings(self, all_connection_strings):
        """
        Sets the all_connection_strings of this DatabaseConnectionStrings.
        All connection strings to use to connect to the Database.


        :param all_connection_strings: The all_connection_strings of this DatabaseConnectionStrings.
        :type: dict(str, str)
        """
        self._all_connection_strings = all_connection_strings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateInstanceAvailabilityConfigDetails(object):
    """
    Options for defining the availability of a VM instance after a maintenance event that impacts the underlying
    hardware, including whether to live migrate supported VM instances when possible without sending a prior customer notification.
    """

    #: A constant which can be used with the recovery_action property of a UpdateInstanceAvailabilityConfigDetails.
    #: This constant has a value of "RESTORE_INSTANCE"
    RECOVERY_ACTION_RESTORE_INSTANCE = "RESTORE_INSTANCE"

    #: A constant which can be used with the recovery_action property of a UpdateInstanceAvailabilityConfigDetails.
    #: This constant has a value of "STOP_INSTANCE"
    RECOVERY_ACTION_STOP_INSTANCE = "STOP_INSTANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateInstanceAvailabilityConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_live_migration_preferred:
            The value to assign to the is_live_migration_preferred property of this UpdateInstanceAvailabilityConfigDetails.
        :type is_live_migration_preferred: bool

        :param recovery_action:
            The value to assign to the recovery_action property of this UpdateInstanceAvailabilityConfigDetails.
            Allowed values for this property are: "RESTORE_INSTANCE", "STOP_INSTANCE"
        :type recovery_action: str

        """
        self.swagger_types = {
            'is_live_migration_preferred': 'bool',
            'recovery_action': 'str'
        }

        self.attribute_map = {
            'is_live_migration_preferred': 'isLiveMigrationPreferred',
            'recovery_action': 'recoveryAction'
        }

        self._is_live_migration_preferred = None
        self._recovery_action = None

    @property
    def is_live_migration_preferred(self):
        """
        Gets the is_live_migration_preferred of this UpdateInstanceAvailabilityConfigDetails.
        Whether to live migrate supported VM instances to a healthy physical VM host without
        disrupting running instances during infrastructure maintenance events. If null, Oracle
        chooses the best option for migrating the VM during infrastructure maintenance events.


        :return: The is_live_migration_preferred of this UpdateInstanceAvailabilityConfigDetails.
        :rtype: bool
        """
        return self._is_live_migration_preferred

    @is_live_migration_preferred.setter
    def is_live_migration_preferred(self, is_live_migration_preferred):
        """
        Sets the is_live_migration_preferred of this UpdateInstanceAvailabilityConfigDetails.
        Whether to live migrate supported VM instances to a healthy physical VM host without
        disrupting running instances during infrastructure maintenance events. If null, Oracle
        chooses the best option for migrating the VM during infrastructure maintenance events.


        :param is_live_migration_preferred: The is_live_migration_preferred of this UpdateInstanceAvailabilityConfigDetails.
        :type: bool
        """
        self._is_live_migration_preferred = is_live_migration_preferred

    @property
    def recovery_action(self):
        """
        Gets the recovery_action of this UpdateInstanceAvailabilityConfigDetails.
        The lifecycle state for an instance when it is recovered after infrastructure maintenance.
        * `RESTORE_INSTANCE` - The instance is restored to the lifecycle state it was in before the maintenance event.
        If the instance was running, it is automatically rebooted. This is the default action when a value is not set.
        * `STOP_INSTANCE` - The instance is recovered in the stopped state.

        Allowed values for this property are: "RESTORE_INSTANCE", "STOP_INSTANCE"


        :return: The recovery_action of this UpdateInstanceAvailabilityConfigDetails.
        :rtype: str
        """
        return self._recovery_action

    @recovery_action.setter
    def recovery_action(self, recovery_action):
        """
        Sets the recovery_action of this UpdateInstanceAvailabilityConfigDetails.
        The lifecycle state for an instance when it is recovered after infrastructure maintenance.
        * `RESTORE_INSTANCE` - The instance is restored to the lifecycle state it was in before the maintenance event.
        If the instance was running, it is automatically rebooted. This is the default action when a value is not set.
        * `STOP_INSTANCE` - The instance is recovered in the stopped state.


        :param recovery_action: The recovery_action of this UpdateInstanceAvailabilityConfigDetails.
        :type: str
        """
        allowed_values = ["RESTORE_INSTANCE", "STOP_INSTANCE"]
        if not value_allowed_none_or_none_sentinel(recovery_action, allowed_values):
            raise ValueError(
                "Invalid value for `recovery_action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._recovery_action = recovery_action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateRecommendedNetworkDetails(object):
    """
    Generates a recommended VM cluster network configuration for an Exadata Cloud@Customer system. Applies to Exadata Cloud@Customer instances only.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateRecommendedNetworkDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this GenerateRecommendedNetworkDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this GenerateRecommendedNetworkDetails.
        :type display_name: str

        :param scan_listener_port_tcp:
            The value to assign to the scan_listener_port_tcp property of this GenerateRecommendedNetworkDetails.
        :type scan_listener_port_tcp: int

        :param scan_listener_port_tcp_ssl:
            The value to assign to the scan_listener_port_tcp_ssl property of this GenerateRecommendedNetworkDetails.
        :type scan_listener_port_tcp_ssl: int

        :param networks:
            The value to assign to the networks property of this GenerateRecommendedNetworkDetails.
        :type networks: list[oci.database.models.InfoForNetworkGenDetails]

        :param dns:
            The value to assign to the dns property of this GenerateRecommendedNetworkDetails.
        :type dns: list[str]

        :param ntp:
            The value to assign to the ntp property of this GenerateRecommendedNetworkDetails.
        :type ntp: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this GenerateRecommendedNetworkDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this GenerateRecommendedNetworkDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'scan_listener_port_tcp': 'int',
            'scan_listener_port_tcp_ssl': 'int',
            'networks': 'list[InfoForNetworkGenDetails]',
            'dns': 'list[str]',
            'ntp': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'scan_listener_port_tcp': 'scanListenerPortTcp',
            'scan_listener_port_tcp_ssl': 'scanListenerPortTcpSsl',
            'networks': 'networks',
            'dns': 'dns',
            'ntp': 'ntp',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._scan_listener_port_tcp = None
        self._scan_listener_port_tcp_ssl = None
        self._networks = None
        self._dns = None
        self._ntp = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this GenerateRecommendedNetworkDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this GenerateRecommendedNetworkDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this GenerateRecommendedNetworkDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this GenerateRecommendedNetworkDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this GenerateRecommendedNetworkDetails.
        The user-friendly name for the VM cluster network. The name does not need to be unique.


        :return: The display_name of this GenerateRecommendedNetworkDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this GenerateRecommendedNetworkDetails.
        The user-friendly name for the VM cluster network. The name does not need to be unique.


        :param display_name: The display_name of this GenerateRecommendedNetworkDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def scan_listener_port_tcp(self):
        """
        Gets the scan_listener_port_tcp of this GenerateRecommendedNetworkDetails.
        The SCAN TCPIP port. Default is 1521.


        :return: The scan_listener_port_tcp of this GenerateRecommendedNetworkDetails.
        :rtype: int
        """
        return self._scan_listener_port_tcp

    @scan_listener_port_tcp.setter
    def scan_listener_port_tcp(self, scan_listener_port_tcp):
        """
        Sets the scan_listener_port_tcp of this GenerateRecommendedNetworkDetails.
        The SCAN TCPIP port. Default is 1521.


        :param scan_listener_port_tcp: The scan_listener_port_tcp of this GenerateRecommendedNetworkDetails.
        :type: int
        """
        self._scan_listener_port_tcp = scan_listener_port_tcp

    @property
    def scan_listener_port_tcp_ssl(self):
        """
        Gets the scan_listener_port_tcp_ssl of this GenerateRecommendedNetworkDetails.
        The SCAN TCPIP SSL port. Default is 2484.


        :return: The scan_listener_port_tcp_ssl of this GenerateRecommendedNetworkDetails.
        :rtype: int
        """
        return self._scan_listener_port_tcp_ssl

    @scan_listener_port_tcp_ssl.setter
    def scan_listener_port_tcp_ssl(self, scan_listener_port_tcp_ssl):
        """
        Sets the scan_listener_port_tcp_ssl of this GenerateRecommendedNetworkDetails.
        The SCAN TCPIP SSL port. Default is 2484.


        :param scan_listener_port_tcp_ssl: The scan_listener_port_tcp_ssl of this GenerateRecommendedNetworkDetails.
        :type: int
        """
        self._scan_listener_port_tcp_ssl = scan_listener_port_tcp_ssl

    @property
    def networks(self):
        """
        **[Required]** Gets the networks of this GenerateRecommendedNetworkDetails.
        List of parameters for generation of the client and backup networks.


        :return: The networks of this GenerateRecommendedNetworkDetails.
        :rtype: list[oci.database.models.InfoForNetworkGenDetails]
        """
        return self._networks

    @networks.setter
    def networks(self, networks):
        """
        Sets the networks of this GenerateRecommendedNetworkDetails.
        List of parameters for generation of the client and backup networks.


        :param networks: The networks of this GenerateRecommendedNetworkDetails.
        :type: list[oci.database.models.InfoForNetworkGenDetails]
        """
        self._networks = networks

    @property
    def dns(self):
        """
        Gets the dns of this GenerateRecommendedNetworkDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :return: The dns of this GenerateRecommendedNetworkDetails.
        :rtype: list[str]
        """
        return self._dns

    @dns.setter
    def dns(self, dns):
        """
        Sets the dns of this GenerateRecommendedNetworkDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :param dns: The dns of this GenerateRecommendedNetworkDetails.
        :type: list[str]
        """
        self._dns = dns

    @property
    def ntp(self):
        """
        Gets the ntp of this GenerateRecommendedNetworkDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :return: The ntp of this GenerateRecommendedNetworkDetails.
        :rtype: list[str]
        """
        return self._ntp

    @ntp.setter
    def ntp(self, ntp):
        """
        Sets the ntp of this GenerateRecommendedNetworkDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :param ntp: The ntp of this GenerateRecommendedNetworkDetails.
        :type: list[str]
        """
        self._ntp = ntp

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this GenerateRecommendedNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this GenerateRecommendedNetworkDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this GenerateRecommendedNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this GenerateRecommendedNetworkDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this GenerateRecommendedNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this GenerateRecommendedNetworkDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this GenerateRecommendedNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this GenerateRecommendedNetworkDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .compute_instance_group_rollout_policy import ComputeInstanceGroupRolloutPolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceGroupLinearRolloutPolicyByPercentage(ComputeInstanceGroupRolloutPolicy):
    """
    Specifies a linear rollout strategy for a compute instance group rolling deployment stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceGroupLinearRolloutPolicyByPercentage object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.ComputeInstanceGroupLinearRolloutPolicyByPercentage.policy_type` attribute
        of this class is ``COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
            Allowed values for this property are: "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT", "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE"
        :type policy_type: str

        :param batch_delay_in_seconds:
            The value to assign to the batch_delay_in_seconds property of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        :type batch_delay_in_seconds: int

        :param batch_percentage:
            The value to assign to the batch_percentage property of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        :type batch_percentage: int

        """
        self.swagger_types = {
            'policy_type': 'str',
            'batch_delay_in_seconds': 'int',
            'batch_percentage': 'int'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'batch_delay_in_seconds': 'batchDelayInSeconds',
            'batch_percentage': 'batchPercentage'
        }

        self._policy_type = None
        self._batch_delay_in_seconds = None
        self._batch_percentage = None
        self._policy_type = 'COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE'

    @property
    def batch_percentage(self):
        """
        **[Required]** Gets the batch_percentage of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        The percentage that will be used to determine how many instances will be deployed concurrently.


        :return: The batch_percentage of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        :rtype: int
        """
        return self._batch_percentage

    @batch_percentage.setter
    def batch_percentage(self, batch_percentage):
        """
        Sets the batch_percentage of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        The percentage that will be used to determine how many instances will be deployed concurrently.


        :param batch_percentage: The batch_percentage of this ComputeInstanceGroupLinearRolloutPolicyByPercentage.
        :type: int
        """
        self._batch_percentage = batch_percentage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrQueryResult(object):
    """
    The AWR query result.
    """

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_SET"
    AWR_RESULT_TYPE_AWRDB_SET = "AWRDB_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_SNAPSHOT_RANGE_SET"
    AWR_RESULT_TYPE_AWRDB_SNAPSHOT_RANGE_SET = "AWRDB_SNAPSHOT_RANGE_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_SNAPSHOT_SET"
    AWR_RESULT_TYPE_AWRDB_SNAPSHOT_SET = "AWRDB_SNAPSHOT_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_METRICS_SET"
    AWR_RESULT_TYPE_AWRDB_METRICS_SET = "AWRDB_METRICS_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_SYSSTAT_SET"
    AWR_RESULT_TYPE_AWRDB_SYSSTAT_SET = "AWRDB_SYSSTAT_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_TOP_EVENT_SET"
    AWR_RESULT_TYPE_AWRDB_TOP_EVENT_SET = "AWRDB_TOP_EVENT_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_EVENT_SET"
    AWR_RESULT_TYPE_AWRDB_EVENT_SET = "AWRDB_EVENT_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_EVENT_HISTOGRAM"
    AWR_RESULT_TYPE_AWRDB_EVENT_HISTOGRAM = "AWRDB_EVENT_HISTOGRAM"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_DB_PARAMETER_SET"
    AWR_RESULT_TYPE_AWRDB_DB_PARAMETER_SET = "AWRDB_DB_PARAMETER_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_DB_PARAMETER_CHANGE"
    AWR_RESULT_TYPE_AWRDB_DB_PARAMETER_CHANGE = "AWRDB_DB_PARAMETER_CHANGE"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_ASH_CPU_USAGE_SET"
    AWR_RESULT_TYPE_AWRDB_ASH_CPU_USAGE_SET = "AWRDB_ASH_CPU_USAGE_SET"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_DB_REPORT"
    AWR_RESULT_TYPE_AWRDB_DB_REPORT = "AWRDB_DB_REPORT"

    #: A constant which can be used with the awr_result_type property of a AwrQueryResult.
    #: This constant has a value of "AWRDB_SQL_REPORT"
    AWR_RESULT_TYPE_AWRDB_SQL_REPORT = "AWRDB_SQL_REPORT"

    def __init__(self, **kwargs):
        """
        Initializes a new AwrQueryResult object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database_management.models.AwrDbParameterChangeCollection`
        * :class:`~oci.database_management.models.AwrDbCpuUsageCollection`
        * :class:`~oci.database_management.models.AwrDbWaitEventBucketCollection`
        * :class:`~oci.database_management.models.AwrDbParameterCollection`
        * :class:`~oci.database_management.models.AwrDbSysstatCollection`
        * :class:`~oci.database_management.models.AwrDbTopWaitEventCollection`
        * :class:`~oci.database_management.models.AwrDbSnapshotCollection`
        * :class:`~oci.database_management.models.AwrDbCollection`
        * :class:`~oci.database_management.models.AwrDbSnapshotRangeCollection`
        * :class:`~oci.database_management.models.AwrDbReport`
        * :class:`~oci.database_management.models.AwrDbMetricCollection`
        * :class:`~oci.database_management.models.AwrDbWaitEventCollection`
        * :class:`~oci.database_management.models.AwrDbSqlReport`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AwrQueryResult.
        :type name: str

        :param version:
            The value to assign to the version property of this AwrQueryResult.
        :type version: str

        :param query_key:
            The value to assign to the query_key property of this AwrQueryResult.
        :type query_key: str

        :param db_query_time_in_secs:
            The value to assign to the db_query_time_in_secs property of this AwrQueryResult.
        :type db_query_time_in_secs: float

        :param awr_result_type:
            The value to assign to the awr_result_type property of this AwrQueryResult.
            Allowed values for this property are: "AWRDB_SET", "AWRDB_SNAPSHOT_RANGE_SET", "AWRDB_SNAPSHOT_SET", "AWRDB_METRICS_SET", "AWRDB_SYSSTAT_SET", "AWRDB_TOP_EVENT_SET", "AWRDB_EVENT_SET", "AWRDB_EVENT_HISTOGRAM", "AWRDB_DB_PARAMETER_SET", "AWRDB_DB_PARAMETER_CHANGE", "AWRDB_ASH_CPU_USAGE_SET", "AWRDB_DB_REPORT", "AWRDB_SQL_REPORT"
        :type awr_result_type: str

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str',
            'query_key': 'str',
            'db_query_time_in_secs': 'float',
            'awr_result_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'query_key': 'queryKey',
            'db_query_time_in_secs': 'dbQueryTimeInSecs',
            'awr_result_type': 'awrResultType'
        }

        self._name = None
        self._version = None
        self._query_key = None
        self._db_query_time_in_secs = None
        self._awr_result_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['awrResultType']

        if type == 'AWRDB_DB_PARAMETER_CHANGE':
            return 'AwrDbParameterChangeCollection'

        if type == 'AWRDB_ASH_CPU_USAGE_SET':
            return 'AwrDbCpuUsageCollection'

        if type == 'AWRDB_EVENT_HISTOGRAM_SET':
            return 'AwrDbWaitEventBucketCollection'

        if type == 'AWRDB_DB_PARAMETER_SET':
            return 'AwrDbParameterCollection'

        if type == 'AWRDB_SYSSTAT_SET':
            return 'AwrDbSysstatCollection'

        if type == 'AWRDB_TOP_EVENT_SET':
            return 'AwrDbTopWaitEventCollection'

        if type == 'AWRDB_SNAPSHOT_SET':
            return 'AwrDbSnapshotCollection'

        if type == 'AWRDB_SET':
            return 'AwrDbCollection'

        if type == 'AWRDB_SNAPSHOT_RANGE_SET':
            return 'AwrDbSnapshotRangeCollection'

        if type == 'AWRDB_DB_REPORT':
            return 'AwrDbReport'

        if type == 'AWRDB_METRICS_SET':
            return 'AwrDbMetricCollection'

        if type == 'AWRDB_EVENT_SET':
            return 'AwrDbWaitEventCollection'

        if type == 'AWRDB_SQL_REPORT':
            return 'AwrDbSqlReport'
        else:
            return 'AwrQueryResult'

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AwrQueryResult.
        The name of the query result.


        :return: The name of this AwrQueryResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AwrQueryResult.
        The name of the query result.


        :param name: The name of this AwrQueryResult.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this AwrQueryResult.
        The version of the query result.


        :return: The version of this AwrQueryResult.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this AwrQueryResult.
        The version of the query result.


        :param version: The version of this AwrQueryResult.
        :type: str
        """
        self._version = version

    @property
    def query_key(self):
        """
        Gets the query_key of this AwrQueryResult.
        The ID assigned to the query instance.


        :return: The query_key of this AwrQueryResult.
        :rtype: str
        """
        return self._query_key

    @query_key.setter
    def query_key(self, query_key):
        """
        Sets the query_key of this AwrQueryResult.
        The ID assigned to the query instance.


        :param query_key: The query_key of this AwrQueryResult.
        :type: str
        """
        self._query_key = query_key

    @property
    def db_query_time_in_secs(self):
        """
        Gets the db_query_time_in_secs of this AwrQueryResult.
        The time taken to query the database tier (in seconds).


        :return: The db_query_time_in_secs of this AwrQueryResult.
        :rtype: float
        """
        return self._db_query_time_in_secs

    @db_query_time_in_secs.setter
    def db_query_time_in_secs(self, db_query_time_in_secs):
        """
        Sets the db_query_time_in_secs of this AwrQueryResult.
        The time taken to query the database tier (in seconds).


        :param db_query_time_in_secs: The db_query_time_in_secs of this AwrQueryResult.
        :type: float
        """
        self._db_query_time_in_secs = db_query_time_in_secs

    @property
    def awr_result_type(self):
        """
        **[Required]** Gets the awr_result_type of this AwrQueryResult.
        The result type of AWR query.

        Allowed values for this property are: "AWRDB_SET", "AWRDB_SNAPSHOT_RANGE_SET", "AWRDB_SNAPSHOT_SET", "AWRDB_METRICS_SET", "AWRDB_SYSSTAT_SET", "AWRDB_TOP_EVENT_SET", "AWRDB_EVENT_SET", "AWRDB_EVENT_HISTOGRAM", "AWRDB_DB_PARAMETER_SET", "AWRDB_DB_PARAMETER_CHANGE", "AWRDB_ASH_CPU_USAGE_SET", "AWRDB_DB_REPORT", "AWRDB_SQL_REPORT"


        :return: The awr_result_type of this AwrQueryResult.
        :rtype: str
        """
        return self._awr_result_type

    @awr_result_type.setter
    def awr_result_type(self, awr_result_type):
        """
        Sets the awr_result_type of this AwrQueryResult.
        The result type of AWR query.


        :param awr_result_type: The awr_result_type of this AwrQueryResult.
        :type: str
        """
        allowed_values = ["AWRDB_SET", "AWRDB_SNAPSHOT_RANGE_SET", "AWRDB_SNAPSHOT_SET", "AWRDB_METRICS_SET", "AWRDB_SYSSTAT_SET", "AWRDB_TOP_EVENT_SET", "AWRDB_EVENT_SET", "AWRDB_EVENT_HISTOGRAM", "AWRDB_DB_PARAMETER_SET", "AWRDB_DB_PARAMETER_CHANGE", "AWRDB_ASH_CPU_USAGE_SET", "AWRDB_DB_REPORT", "AWRDB_SQL_REPORT"]
        if not value_allowed_none_or_none_sentinel(awr_result_type, allowed_values):
            raise ValueError(
                "Invalid value for `awr_result_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._awr_result_type = awr_result_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsEmBridgeSummary(object):
    """
    Enterprise manager bridge summary.
    """

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    #: A constant which can be used with the last_import_processing_status property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "NOT_STARTED"
    LAST_IMPORT_PROCESSING_STATUS_NOT_STARTED = "NOT_STARTED"

    #: A constant which can be used with the last_import_processing_status property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "SUCCESS"
    LAST_IMPORT_PROCESSING_STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the last_import_processing_status property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "IN_PROGRESS"
    LAST_IMPORT_PROCESSING_STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the last_import_processing_status property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "FAILED"
    LAST_IMPORT_PROCESSING_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the last_import_processing_status property of a LogAnalyticsEmBridgeSummary.
    #: This constant has a value of "PARTIAL_SUCCESS"
    LAST_IMPORT_PROCESSING_STATUS_PARTIAL_SUCCESS = "PARTIAL_SUCCESS"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsEmBridgeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this LogAnalyticsEmBridgeSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsEmBridgeSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this LogAnalyticsEmBridgeSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsEmBridgeSummary.
        :type compartment_id: str

        :param em_entities_compartment_id:
            The value to assign to the em_entities_compartment_id property of this LogAnalyticsEmBridgeSummary.
        :type em_entities_compartment_id: str

        :param bucket_name:
            The value to assign to the bucket_name property of this LogAnalyticsEmBridgeSummary.
        :type bucket_name: str

        :param time_created:
            The value to assign to the time_created property of this LogAnalyticsEmBridgeSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsEmBridgeSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LogAnalyticsEmBridgeSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this LogAnalyticsEmBridgeSummary.
        :type lifecycle_details: str

        :param last_import_processing_status:
            The value to assign to the last_import_processing_status property of this LogAnalyticsEmBridgeSummary.
            Allowed values for this property are: "NOT_STARTED", "SUCCESS", "IN_PROGRESS", "FAILED", "PARTIAL_SUCCESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type last_import_processing_status: str

        :param last_import_processing_details:
            The value to assign to the last_import_processing_details property of this LogAnalyticsEmBridgeSummary.
        :type last_import_processing_details: str

        :param time_import_last_processed:
            The value to assign to the time_import_last_processed property of this LogAnalyticsEmBridgeSummary.
        :type time_import_last_processed: datetime

        :param time_em_data_last_extracted:
            The value to assign to the time_em_data_last_extracted property of this LogAnalyticsEmBridgeSummary.
        :type time_em_data_last_extracted: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this LogAnalyticsEmBridgeSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this LogAnalyticsEmBridgeSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'em_entities_compartment_id': 'str',
            'bucket_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'last_import_processing_status': 'str',
            'last_import_processing_details': 'str',
            'time_import_last_processed': 'datetime',
            'time_em_data_last_extracted': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'em_entities_compartment_id': 'emEntitiesCompartmentId',
            'bucket_name': 'bucketName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'last_import_processing_status': 'lastImportProcessingStatus',
            'last_import_processing_details': 'lastImportProcessingDetails',
            'time_import_last_processed': 'timeImportLastProcessed',
            'time_em_data_last_extracted': 'timeEmDataLastExtracted',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._em_entities_compartment_id = None
        self._bucket_name = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._last_import_processing_status = None
        self._last_import_processing_details = None
        self._time_import_last_processed = None
        self._time_em_data_last_extracted = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this LogAnalyticsEmBridgeSummary.
        The enterprise manager bridge OCID.


        :return: The id of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LogAnalyticsEmBridgeSummary.
        The enterprise manager bridge OCID.


        :param id: The id of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this LogAnalyticsEmBridgeSummary.
        Log analytics enterprise manager bridge display name.


        :return: The display_name of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsEmBridgeSummary.
        Log analytics enterprise manager bridge display name.


        :param display_name: The display_name of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsEmBridgeSummary.
        A description for log analytics enterprise manager bridge.


        :return: The description of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsEmBridgeSummary.
        A description for log analytics enterprise manager bridge.


        :param description: The description of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LogAnalyticsEmBridgeSummary.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsEmBridgeSummary.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def em_entities_compartment_id(self):
        """
        **[Required]** Gets the em_entities_compartment_id of this LogAnalyticsEmBridgeSummary.
        Compartment for entities created from enterprise manager.


        :return: The em_entities_compartment_id of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._em_entities_compartment_id

    @em_entities_compartment_id.setter
    def em_entities_compartment_id(self, em_entities_compartment_id):
        """
        Sets the em_entities_compartment_id of this LogAnalyticsEmBridgeSummary.
        Compartment for entities created from enterprise manager.


        :param em_entities_compartment_id: The em_entities_compartment_id of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._em_entities_compartment_id = em_entities_compartment_id

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this LogAnalyticsEmBridgeSummary.
        Object store bucket name where enterprise manager harvested entities will be uploaded.


        :return: The bucket_name of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this LogAnalyticsEmBridgeSummary.
        Object store bucket name where enterprise manager harvested entities will be uploaded.


        :param bucket_name: The bucket_name of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this LogAnalyticsEmBridgeSummary.
        The date and time the resource was created, in the format defined by RFC3339.


        :return: The time_created of this LogAnalyticsEmBridgeSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this LogAnalyticsEmBridgeSummary.
        The date and time the resource was created, in the format defined by RFC3339.


        :param time_created: The time_created of this LogAnalyticsEmBridgeSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this LogAnalyticsEmBridgeSummary.
        The date and time the resource was last updated, in the format defined by RFC3339.


        :return: The time_updated of this LogAnalyticsEmBridgeSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsEmBridgeSummary.
        The date and time the resource was last updated, in the format defined by RFC3339.


        :param time_updated: The time_updated of this LogAnalyticsEmBridgeSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this LogAnalyticsEmBridgeSummary.
        The current state of the enterprise manager bridge.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LogAnalyticsEmBridgeSummary.
        The current state of the enterprise manager bridge.


        :param lifecycle_state: The lifecycle_state of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETED", "NEEDS_ATTENTION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this LogAnalyticsEmBridgeSummary.
        lifecycleDetails has additional information regarding substeps such as verifying connection to object store.


        :return: The lifecycle_details of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this LogAnalyticsEmBridgeSummary.
        lifecycleDetails has additional information regarding substeps such as verifying connection to object store.


        :param lifecycle_details: The lifecycle_details of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def last_import_processing_status(self):
        """
        **[Required]** Gets the last_import_processing_status of this LogAnalyticsEmBridgeSummary.
        The status from last processing status of enterprise manager upload.

        Allowed values for this property are: "NOT_STARTED", "SUCCESS", "IN_PROGRESS", "FAILED", "PARTIAL_SUCCESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The last_import_processing_status of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._last_import_processing_status

    @last_import_processing_status.setter
    def last_import_processing_status(self, last_import_processing_status):
        """
        Sets the last_import_processing_status of this LogAnalyticsEmBridgeSummary.
        The status from last processing status of enterprise manager upload.


        :param last_import_processing_status: The last_import_processing_status of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        allowed_values = ["NOT_STARTED", "SUCCESS", "IN_PROGRESS", "FAILED", "PARTIAL_SUCCESS"]
        if not value_allowed_none_or_none_sentinel(last_import_processing_status, allowed_values):
            last_import_processing_status = 'UNKNOWN_ENUM_VALUE'
        self._last_import_processing_status = last_import_processing_status

    @property
    def last_import_processing_details(self):
        """
        Gets the last_import_processing_details of this LogAnalyticsEmBridgeSummary.
        Processing status details of enterprise manager upload. This provides additional details
        for failed status


        :return: The last_import_processing_details of this LogAnalyticsEmBridgeSummary.
        :rtype: str
        """
        return self._last_import_processing_details

    @last_import_processing_details.setter
    def last_import_processing_details(self, last_import_processing_details):
        """
        Sets the last_import_processing_details of this LogAnalyticsEmBridgeSummary.
        Processing status details of enterprise manager upload. This provides additional details
        for failed status


        :param last_import_processing_details: The last_import_processing_details of this LogAnalyticsEmBridgeSummary.
        :type: str
        """
        self._last_import_processing_details = last_import_processing_details

    @property
    def time_import_last_processed(self):
        """
        Gets the time_import_last_processed of this LogAnalyticsEmBridgeSummary.
        The last time of enterprise manager upload was processed. This is in the format defined by RFC3339


        :return: The time_import_last_processed of this LogAnalyticsEmBridgeSummary.
        :rtype: datetime
        """
        return self._time_import_last_processed

    @time_import_last_processed.setter
    def time_import_last_processed(self, time_import_last_processed):
        """
        Sets the time_import_last_processed of this LogAnalyticsEmBridgeSummary.
        The last time of enterprise manager upload was processed. This is in the format defined by RFC3339


        :param time_import_last_processed: The time_import_last_processed of this LogAnalyticsEmBridgeSummary.
        :type: datetime
        """
        self._time_import_last_processed = time_import_last_processed

    @property
    def time_em_data_last_extracted(self):
        """
        Gets the time_em_data_last_extracted of this LogAnalyticsEmBridgeSummary.
        The timestamp of last enterprise manager upload to OCI Object Store. This is in the format defined by RFC3339


        :return: The time_em_data_last_extracted of this LogAnalyticsEmBridgeSummary.
        :rtype: datetime
        """
        return self._time_em_data_last_extracted

    @time_em_data_last_extracted.setter
    def time_em_data_last_extracted(self, time_em_data_last_extracted):
        """
        Sets the time_em_data_last_extracted of this LogAnalyticsEmBridgeSummary.
        The timestamp of last enterprise manager upload to OCI Object Store. This is in the format defined by RFC3339


        :param time_em_data_last_extracted: The time_em_data_last_extracted of this LogAnalyticsEmBridgeSummary.
        :type: datetime
        """
        self._time_em_data_last_extracted = time_em_data_last_extracted

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this LogAnalyticsEmBridgeSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this LogAnalyticsEmBridgeSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this LogAnalyticsEmBridgeSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this LogAnalyticsEmBridgeSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this LogAnalyticsEmBridgeSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this LogAnalyticsEmBridgeSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this LogAnalyticsEmBridgeSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this LogAnalyticsEmBridgeSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateHeatWaveClusterDetails(object):
    """
    Details about the HeatWave cluster properties to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateHeatWaveClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param shape_name:
            The value to assign to the shape_name property of this UpdateHeatWaveClusterDetails.
        :type shape_name: str

        :param cluster_size:
            The value to assign to the cluster_size property of this UpdateHeatWaveClusterDetails.
        :type cluster_size: int

        """
        self.swagger_types = {
            'shape_name': 'str',
            'cluster_size': 'int'
        }

        self.attribute_map = {
            'shape_name': 'shapeName',
            'cluster_size': 'clusterSize'
        }

        self._shape_name = None
        self._cluster_size = None

    @property
    def shape_name(self):
        """
        Gets the shape_name of this UpdateHeatWaveClusterDetails.
        A change to the shape of the nodes in the HeatWave cluster will
        result in the entire cluster being torn down and re-created with
        Compute instances of the new Shape. This may result in significant
        downtime for the analytics capability while the HeatWave cluster is
        re-provisioned.


        :return: The shape_name of this UpdateHeatWaveClusterDetails.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this UpdateHeatWaveClusterDetails.
        A change to the shape of the nodes in the HeatWave cluster will
        result in the entire cluster being torn down and re-created with
        Compute instances of the new Shape. This may result in significant
        downtime for the analytics capability while the HeatWave cluster is
        re-provisioned.


        :param shape_name: The shape_name of this UpdateHeatWaveClusterDetails.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def cluster_size(self):
        """
        Gets the cluster_size of this UpdateHeatWaveClusterDetails.
        A change to the number of nodes in the HeatWave cluster will result
        in the entire cluster being torn down and re-created with the new
        cluster of nodes. This may result in a significant downtime for the
        analytics capability while the HeatWave cluster is
        re-provisioned.


        :return: The cluster_size of this UpdateHeatWaveClusterDetails.
        :rtype: int
        """
        return self._cluster_size

    @cluster_size.setter
    def cluster_size(self, cluster_size):
        """
        Sets the cluster_size of this UpdateHeatWaveClusterDetails.
        A change to the number of nodes in the HeatWave cluster will result
        in the entire cluster being torn down and re-created with the new
        cluster of nodes. This may result in a significant downtime for the
        analytics capability while the HeatWave cluster is
        re-provisioned.


        :param cluster_size: The cluster_size of this UpdateHeatWaveClusterDetails.
        :type: int
        """
        self._cluster_size = cluster_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestSummarizedManagedInstanceUsageDetails(object):
    """
    Parameters for filtering managed instances.
    """

    #: A constant which can be used with the managed_instance_type property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "ORACLE_MANAGEMENT_AGENT"
    MANAGED_INSTANCE_TYPE_ORACLE_MANAGEMENT_AGENT = "ORACLE_MANAGEMENT_AGENT"

    #: A constant which can be used with the sort_order property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "ASC"
    SORT_ORDER_ASC = "ASC"

    #: A constant which can be used with the sort_order property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "DESC"
    SORT_ORDER_DESC = "DESC"

    #: A constant which can be used with the sort_by property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "timeFirstSeen"
    SORT_BY_TIME_FIRST_SEEN = "timeFirstSeen"

    #: A constant which can be used with the sort_by property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "timeLastSeen"
    SORT_BY_TIME_LAST_SEEN = "timeLastSeen"

    #: A constant which can be used with the sort_by property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "approximateJreCount"
    SORT_BY_APPROXIMATE_JRE_COUNT = "approximateJreCount"

    #: A constant which can be used with the sort_by property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "approximateInstallationCount"
    SORT_BY_APPROXIMATE_INSTALLATION_COUNT = "approximateInstallationCount"

    #: A constant which can be used with the sort_by property of a RequestSummarizedManagedInstanceUsageDetails.
    #: This constant has a value of "approximateApplicationCount"
    SORT_BY_APPROXIMATE_APPLICATION_COUNT = "approximateApplicationCount"

    def __init__(self, **kwargs):
        """
        Initializes a new RequestSummarizedManagedInstanceUsageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_start:
            The value to assign to the time_start property of this RequestSummarizedManagedInstanceUsageDetails.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this RequestSummarizedManagedInstanceUsageDetails.
        :type time_end: datetime

        :param installation_path:
            The value to assign to the installation_path property of this RequestSummarizedManagedInstanceUsageDetails.
        :type installation_path: str

        :param jre_vendor:
            The value to assign to the jre_vendor property of this RequestSummarizedManagedInstanceUsageDetails.
        :type jre_vendor: str

        :param jre_distribution:
            The value to assign to the jre_distribution property of this RequestSummarizedManagedInstanceUsageDetails.
        :type jre_distribution: str

        :param jre_version:
            The value to assign to the jre_version property of this RequestSummarizedManagedInstanceUsageDetails.
        :type jre_version: str

        :param application_id:
            The value to assign to the application_id property of this RequestSummarizedManagedInstanceUsageDetails.
        :type application_id: str

        :param managed_instance_id:
            The value to assign to the managed_instance_id property of this RequestSummarizedManagedInstanceUsageDetails.
        :type managed_instance_id: str

        :param managed_instance_type:
            The value to assign to the managed_instance_type property of this RequestSummarizedManagedInstanceUsageDetails.
            Allowed values for this property are: "ORACLE_MANAGEMENT_AGENT"
        :type managed_instance_type: str

        :param sort_order:
            The value to assign to the sort_order property of this RequestSummarizedManagedInstanceUsageDetails.
            Allowed values for this property are: "ASC", "DESC"
        :type sort_order: str

        :param sort_by:
            The value to assign to the sort_by property of this RequestSummarizedManagedInstanceUsageDetails.
            Allowed values for this property are: "timeFirstSeen", "timeLastSeen", "approximateJreCount", "approximateInstallationCount", "approximateApplicationCount"
        :type sort_by: str

        :param fields:
            The value to assign to the fields property of this RequestSummarizedManagedInstanceUsageDetails.
        :type fields: list[oci.jms.models.SummarizeManagedInstanceUsageFields]

        """
        self.swagger_types = {
            'time_start': 'datetime',
            'time_end': 'datetime',
            'installation_path': 'str',
            'jre_vendor': 'str',
            'jre_distribution': 'str',
            'jre_version': 'str',
            'application_id': 'str',
            'managed_instance_id': 'str',
            'managed_instance_type': 'str',
            'sort_order': 'str',
            'sort_by': 'str',
            'fields': 'list[SummarizeManagedInstanceUsageFields]'
        }

        self.attribute_map = {
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'installation_path': 'installationPath',
            'jre_vendor': 'jreVendor',
            'jre_distribution': 'jreDistribution',
            'jre_version': 'jreVersion',
            'application_id': 'applicationId',
            'managed_instance_id': 'managedInstanceId',
            'managed_instance_type': 'managedInstanceType',
            'sort_order': 'sortOrder',
            'sort_by': 'sortBy',
            'fields': 'fields'
        }

        self._time_start = None
        self._time_end = None
        self._installation_path = None
        self._jre_vendor = None
        self._jre_distribution = None
        self._jre_version = None
        self._application_id = None
        self._managed_instance_id = None
        self._managed_instance_type = None
        self._sort_order = None
        self._sort_by = None
        self._fields = None

    @property
    def time_start(self):
        """
        Gets the time_start of this RequestSummarizedManagedInstanceUsageDetails.
        The start of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time minus seven days.


        :return: The time_start of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this RequestSummarizedManagedInstanceUsageDetails.
        The start of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time minus seven days.


        :param time_start: The time_start of this RequestSummarizedManagedInstanceUsageDetails.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this RequestSummarizedManagedInstanceUsageDetails.
        The end of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time.


        :return: The time_end of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this RequestSummarizedManagedInstanceUsageDetails.
        The end of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time.


        :param time_end: The time_end of this RequestSummarizedManagedInstanceUsageDetails.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def installation_path(self):
        """
        Gets the installation_path of this RequestSummarizedManagedInstanceUsageDetails.
        The installation path of the related installation.


        :return: The installation_path of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._installation_path

    @installation_path.setter
    def installation_path(self, installation_path):
        """
        Sets the installation_path of this RequestSummarizedManagedInstanceUsageDetails.
        The installation path of the related installation.


        :param installation_path: The installation_path of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._installation_path = installation_path

    @property
    def jre_vendor(self):
        """
        Gets the jre_vendor of this RequestSummarizedManagedInstanceUsageDetails.
        The vendor of the related Java Runtime.


        :return: The jre_vendor of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._jre_vendor

    @jre_vendor.setter
    def jre_vendor(self, jre_vendor):
        """
        Sets the jre_vendor of this RequestSummarizedManagedInstanceUsageDetails.
        The vendor of the related Java Runtime.


        :param jre_vendor: The jre_vendor of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._jre_vendor = jre_vendor

    @property
    def jre_distribution(self):
        """
        Gets the jre_distribution of this RequestSummarizedManagedInstanceUsageDetails.
        The distribution of the related Java Runtime.


        :return: The jre_distribution of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._jre_distribution

    @jre_distribution.setter
    def jre_distribution(self, jre_distribution):
        """
        Sets the jre_distribution of this RequestSummarizedManagedInstanceUsageDetails.
        The distribution of the related Java Runtime.


        :param jre_distribution: The jre_distribution of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._jre_distribution = jre_distribution

    @property
    def jre_version(self):
        """
        Gets the jre_version of this RequestSummarizedManagedInstanceUsageDetails.
        The version of the related Java Runtime.


        :return: The jre_version of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._jre_version

    @jre_version.setter
    def jre_version(self, jre_version):
        """
        Sets the jre_version of this RequestSummarizedManagedInstanceUsageDetails.
        The version of the related Java Runtime.


        :param jre_version: The jre_version of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._jre_version = jre_version

    @property
    def application_id(self):
        """
        Gets the application_id of this RequestSummarizedManagedInstanceUsageDetails.
        The ID of the related application.


        :return: The application_id of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this RequestSummarizedManagedInstanceUsageDetails.
        The ID of the related application.


        :param application_id: The application_id of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._application_id = application_id

    @property
    def managed_instance_id(self):
        """
        Gets the managed_instance_id of this RequestSummarizedManagedInstanceUsageDetails.
        The ID of the managed instance.


        :return: The managed_instance_id of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._managed_instance_id

    @managed_instance_id.setter
    def managed_instance_id(self, managed_instance_id):
        """
        Sets the managed_instance_id of this RequestSummarizedManagedInstanceUsageDetails.
        The ID of the managed instance.


        :param managed_instance_id: The managed_instance_id of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        self._managed_instance_id = managed_instance_id

    @property
    def managed_instance_type(self):
        """
        Gets the managed_instance_type of this RequestSummarizedManagedInstanceUsageDetails.
        type of the managed instance

        Allowed values for this property are: "ORACLE_MANAGEMENT_AGENT"


        :return: The managed_instance_type of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._managed_instance_type

    @managed_instance_type.setter
    def managed_instance_type(self, managed_instance_type):
        """
        Sets the managed_instance_type of this RequestSummarizedManagedInstanceUsageDetails.
        type of the managed instance


        :param managed_instance_type: The managed_instance_type of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        allowed_values = ["ORACLE_MANAGEMENT_AGENT"]
        if not value_allowed_none_or_none_sentinel(managed_instance_type, allowed_values):
            raise ValueError(
                "Invalid value for `managed_instance_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._managed_instance_type = managed_instance_type

    @property
    def sort_order(self):
        """
        Gets the sort_order of this RequestSummarizedManagedInstanceUsageDetails.
        The sort order to use, either 'asc' or 'desc'.

        Allowed values for this property are: "ASC", "DESC"


        :return: The sort_order of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """
        Sets the sort_order of this RequestSummarizedManagedInstanceUsageDetails.
        The sort order to use, either 'asc' or 'desc'.


        :param sort_order: The sort_order of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        allowed_values = ["ASC", "DESC"]
        if not value_allowed_none_or_none_sentinel(sort_order, allowed_values):
            raise ValueError(
                "Invalid value for `sort_order`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_order = sort_order

    @property
    def sort_by(self):
        """
        Gets the sort_by of this RequestSummarizedManagedInstanceUsageDetails.
        The field to sort managed instance views. Only one sort order may be provided.
        Default order for _timeFirstSeen_, _timeLastSeen_, approximateJreCount_, _approximateInstallationCount_
        and _approximateApplicationCount_  is **descending**.
        If no value is specified _timeLastSeen_ is default.

        Allowed values for this property are: "timeFirstSeen", "timeLastSeen", "approximateJreCount", "approximateInstallationCount", "approximateApplicationCount"


        :return: The sort_by of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """
        Sets the sort_by of this RequestSummarizedManagedInstanceUsageDetails.
        The field to sort managed instance views. Only one sort order may be provided.
        Default order for _timeFirstSeen_, _timeLastSeen_, approximateJreCount_, _approximateInstallationCount_
        and _approximateApplicationCount_  is **descending**.
        If no value is specified _timeLastSeen_ is default.


        :param sort_by: The sort_by of this RequestSummarizedManagedInstanceUsageDetails.
        :type: str
        """
        allowed_values = ["timeFirstSeen", "timeLastSeen", "approximateJreCount", "approximateInstallationCount", "approximateApplicationCount"]
        if not value_allowed_none_or_none_sentinel(sort_by, allowed_values):
            raise ValueError(
                "Invalid value for `sort_by`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_by = sort_by

    @property
    def fields(self):
        """
        Gets the fields of this RequestSummarizedManagedInstanceUsageDetails.
        Additional fields to include into the returned model on top of the required ones.
        This parameter can also include 'approximateJreCount', 'approximateInstallationCount' and 'approximateApplicationCount'.
        For example 'approximateJreCount,approximateInstallationCount'.


        :return: The fields of this RequestSummarizedManagedInstanceUsageDetails.
        :rtype: list[oci.jms.models.SummarizeManagedInstanceUsageFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this RequestSummarizedManagedInstanceUsageDetails.
        Additional fields to include into the returned model on top of the required ones.
        This parameter can also include 'approximateJreCount', 'approximateInstallationCount' and 'approximateApplicationCount'.
        For example 'approximateJreCount,approximateInstallationCount'.


        :param fields: The fields of this RequestSummarizedManagedInstanceUsageDetails.
        :type: list[oci.jms.models.SummarizeManagedInstanceUsageFields]
        """
        self._fields = fields

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SummarizeHostInsightResourceUtilizationInsightAggregation(object):
    """
    Insights response containing current/projected groups for CPU or memory.
    """

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceUtilizationInsightAggregation.
    #: This constant has a value of "CPU"
    RESOURCE_METRIC_CPU = "CPU"

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceUtilizationInsightAggregation.
    #: This constant has a value of "MEMORY"
    RESOURCE_METRIC_MEMORY = "MEMORY"

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceUtilizationInsightAggregation.
    #: This constant has a value of "LOGICAL_MEMORY"
    RESOURCE_METRIC_LOGICAL_MEMORY = "LOGICAL_MEMORY"

    def __init__(self, **kwargs):
        """
        Initializes a new SummarizeHostInsightResourceUtilizationInsightAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_interval_start:
            The value to assign to the time_interval_start property of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type time_interval_start: datetime

        :param time_interval_end:
            The value to assign to the time_interval_end property of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type time_interval_end: datetime

        :param resource_metric:
            The value to assign to the resource_metric property of this SummarizeHostInsightResourceUtilizationInsightAggregation.
            Allowed values for this property are: "CPU", "MEMORY", "LOGICAL_MEMORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_metric: str

        :param projected_utilization:
            The value to assign to the projected_utilization property of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type projected_utilization: oci.opsi.models.ResourceInsightProjectedUtilization

        :param current_utilization:
            The value to assign to the current_utilization property of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type current_utilization: oci.opsi.models.ResourceInsightCurrentUtilization

        """
        self.swagger_types = {
            'time_interval_start': 'datetime',
            'time_interval_end': 'datetime',
            'resource_metric': 'str',
            'projected_utilization': 'ResourceInsightProjectedUtilization',
            'current_utilization': 'ResourceInsightCurrentUtilization'
        }

        self.attribute_map = {
            'time_interval_start': 'timeIntervalStart',
            'time_interval_end': 'timeIntervalEnd',
            'resource_metric': 'resourceMetric',
            'projected_utilization': 'projectedUtilization',
            'current_utilization': 'currentUtilization'
        }

        self._time_interval_start = None
        self._time_interval_end = None
        self._resource_metric = None
        self._projected_utilization = None
        self._current_utilization = None

    @property
    def time_interval_start(self):
        """
        **[Required]** Gets the time_interval_start of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        The start timestamp that was passed into the request.


        :return: The time_interval_start of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :rtype: datetime
        """
        return self._time_interval_start

    @time_interval_start.setter
    def time_interval_start(self, time_interval_start):
        """
        Sets the time_interval_start of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        The start timestamp that was passed into the request.


        :param time_interval_start: The time_interval_start of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type: datetime
        """
        self._time_interval_start = time_interval_start

    @property
    def time_interval_end(self):
        """
        **[Required]** Gets the time_interval_end of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        The end timestamp that was passed into the request.


        :return: The time_interval_end of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :rtype: datetime
        """
        return self._time_interval_end

    @time_interval_end.setter
    def time_interval_end(self, time_interval_end):
        """
        Sets the time_interval_end of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        The end timestamp that was passed into the request.


        :param time_interval_end: The time_interval_end of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type: datetime
        """
        self._time_interval_end = time_interval_end

    @property
    def resource_metric(self):
        """
        **[Required]** Gets the resource_metric of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        Defines the type of resource metric (CPU, Physical Memory, Logical Memory)

        Allowed values for this property are: "CPU", "MEMORY", "LOGICAL_MEMORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_metric of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :rtype: str
        """
        return self._resource_metric

    @resource_metric.setter
    def resource_metric(self, resource_metric):
        """
        Sets the resource_metric of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        Defines the type of resource metric (CPU, Physical Memory, Logical Memory)


        :param resource_metric: The resource_metric of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type: str
        """
        allowed_values = ["CPU", "MEMORY", "LOGICAL_MEMORY"]
        if not value_allowed_none_or_none_sentinel(resource_metric, allowed_values):
            resource_metric = 'UNKNOWN_ENUM_VALUE'
        self._resource_metric = resource_metric

    @property
    def projected_utilization(self):
        """
        **[Required]** Gets the projected_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.

        :return: The projected_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :rtype: oci.opsi.models.ResourceInsightProjectedUtilization
        """
        return self._projected_utilization

    @projected_utilization.setter
    def projected_utilization(self, projected_utilization):
        """
        Sets the projected_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.

        :param projected_utilization: The projected_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type: oci.opsi.models.ResourceInsightProjectedUtilization
        """
        self._projected_utilization = projected_utilization

    @property
    def current_utilization(self):
        """
        **[Required]** Gets the current_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.

        :return: The current_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :rtype: oci.opsi.models.ResourceInsightCurrentUtilization
        """
        return self._current_utilization

    @current_utilization.setter
    def current_utilization(self, current_utilization):
        """
        Sets the current_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.

        :param current_utilization: The current_utilization of this SummarizeHostInsightResourceUtilizationInsightAggregation.
        :type: oci.opsi.models.ResourceInsightCurrentUtilization
        """
        self._current_utilization = current_utilization

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RoverNodeGetRpt(object):
    """
    The resource principal token response.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RoverNodeGetRpt object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_principal_token:
            The value to assign to the resource_principal_token property of this RoverNodeGetRpt.
        :type resource_principal_token: str

        :param service_principal_session_token:
            The value to assign to the service_principal_session_token property of this RoverNodeGetRpt.
        :type service_principal_session_token: str

        """
        self.swagger_types = {
            'resource_principal_token': 'str',
            'service_principal_session_token': 'str'
        }

        self.attribute_map = {
            'resource_principal_token': 'resourcePrincipalToken',
            'service_principal_session_token': 'servicePrincipalSessionToken'
        }

        self._resource_principal_token = None
        self._service_principal_session_token = None

    @property
    def resource_principal_token(self):
        """
        **[Required]** Gets the resource_principal_token of this RoverNodeGetRpt.
        The resource principal token blob that contains claims about the resource.


        :return: The resource_principal_token of this RoverNodeGetRpt.
        :rtype: str
        """
        return self._resource_principal_token

    @resource_principal_token.setter
    def resource_principal_token(self, resource_principal_token):
        """
        Sets the resource_principal_token of this RoverNodeGetRpt.
        The resource principal token blob that contains claims about the resource.


        :param resource_principal_token: The resource_principal_token of this RoverNodeGetRpt.
        :type: str
        """
        self._resource_principal_token = resource_principal_token

    @property
    def service_principal_session_token(self):
        """
        Gets the service_principal_session_token of this RoverNodeGetRpt.
        The service principal session token


        :return: The service_principal_session_token of this RoverNodeGetRpt.
        :rtype: str
        """
        return self._service_principal_session_token

    @service_principal_session_token.setter
    def service_principal_session_token(self, service_principal_session_token):
        """
        Sets the service_principal_session_token of this RoverNodeGetRpt.
        The service principal session token


        :param service_principal_session_token: The service_principal_session_token of this RoverNodeGetRpt.
        :type: str
        """
        self._service_principal_session_token = service_principal_session_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
